package sun.reflect;

import java.lang.reflect.Field;

class UnsafeLongFieldAccessorImpl extends UnsafeFieldAccessorImpl
{
    UnsafeLongFieldAccessorImpl(Field field) {
        super(field);
    }
    
    @Override
    public Object get(Object o) throws IllegalArgumentException {
        return new Long(this.getLong(o));
    }
    
    @Override
    public boolean getBoolean(Object o) throws IllegalArgumentException {
        throw this.newGetBooleanIllegalArgumentException();
    }
    
    @Override
    public byte getByte(Object o) throws IllegalArgumentException {
        throw this.newGetByteIllegalArgumentException();
    }
    
    @Override
    public char getChar(Object o) throws IllegalArgumentException {
        throw this.newGetCharIllegalArgumentException();
    }
    
    @Override
    public short getShort(Object o) throws IllegalArgumentException {
        throw this.newGetShortIllegalArgumentException();
    }
    
    @Override
    public int getInt(Object o) throws IllegalArgumentException {
        throw this.newGetIntIllegalArgumentException();
    }
    
    @Override
    public long getLong(Object o) throws IllegalArgumentException {
        this.ensureObj(o);
        return UnsafeLongFieldAccessorImpl.unsafe.getLong(o, this.fieldOffset);
    }
    
    @Override
    public float getFloat(Object o) throws IllegalArgumentException {
        return (float)this.getLong(o);
    }
    
    @Override
    public double getDouble(Object o) throws IllegalArgumentException {
        return (double)this.getLong(o);
    }
    
    @Override
    public void set(Object o, Object o2) throws IllegalArgumentException, IllegalAccessException {
        this.ensureObj(o);
        if (this.isFinal) {
            this.throwFinalFieldIllegalAccessException(o2);
        }
        if (o2 == null) {
            this.throwSetIllegalArgumentException(o2);
        }
        if ((o2 instanceof Byte)) {
            UnsafeLongFieldAccessorImpl.unsafe.putLong(o, this.fieldOffset, (long)(byte)o2);
            return;
        }
        if ((o2 instanceof Short)) {
            UnsafeLongFieldAccessorImpl.unsafe.putLong(o, this.fieldOffset, (long)(short)o2);
            return;
        }
        if ((o2 instanceof Character)) {
            UnsafeLongFieldAccessorImpl.unsafe.putLong(o, this.fieldOffset, (long)(char)o2);
            return;
        }
        if ((o2 instanceof Integer)) {
            UnsafeLongFieldAccessorImpl.unsafe.putLong(o, this.fieldOffset, (long)(int)o2);
            return;
        }
        if ((o2 instanceof Long)) {
            UnsafeLongFieldAccessorImpl.unsafe.putLong(o, this.fieldOffset, (long)o2);
            return;
        }
        this.throwSetIllegalArgumentException(o2);
        return;
    }
    
    @Override
    public void setBoolean(Object o, boolean b) throws IllegalArgumentException, IllegalAccessException {
        this.throwSetIllegalArgumentException(b);
    }
    
    @Override
    public void setByte(Object o, byte b) throws IllegalArgumentException, IllegalAccessException {
        this.setLong(o, (long)b);
    }
    
    @Override
    public void setChar(Object o, char c) throws IllegalArgumentException, IllegalAccessException {
        this.setLong(o, (long)c);
    }
    
    @Override
    public void setShort(Object o, short n) throws IllegalArgumentException, IllegalAccessException {
        this.setLong(o, (long)n);
    }
    
    @Override
    public void setInt(Object o, int n) throws IllegalArgumentException, IllegalAccessException {
        this.setLong(o, (long)n);
    }
    
    @Override
    public void setLong(Object o, long x) throws IllegalArgumentException, IllegalAccessException {
        this.ensureObj(o);
        if (this.isFinal) {
            this.throwFinalFieldIllegalAccessException(x);
        }
        UnsafeLongFieldAccessorImpl.unsafe.putLong(o, this.fieldOffset, x);
    }
    
    @Override
    public void setFloat(Object o, float n) throws IllegalArgumentException, IllegalAccessException {
        this.throwSetIllegalArgumentException(n);
    }
    
    @Override
    public void setDouble(Object o, double n) throws IllegalArgumentException, IllegalAccessException {
        this.throwSetIllegalArgumentException(n);
    }
}
